# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.bidding_pb2 import (
    Commission as google___ads___googleads___v3___common___bidding_pb2___Commission,
    ManualCpc as google___ads___googleads___v3___common___bidding_pb2___ManualCpc,
    ManualCpm as google___ads___googleads___v3___common___bidding_pb2___ManualCpm,
    ManualCpv as google___ads___googleads___v3___common___bidding_pb2___ManualCpv,
    MaximizeConversions as google___ads___googleads___v3___common___bidding_pb2___MaximizeConversions,
    MaximizeConversionValue as google___ads___googleads___v3___common___bidding_pb2___MaximizeConversionValue,
    PercentCpc as google___ads___googleads___v3___common___bidding_pb2___PercentCpc,
    TargetCpa as google___ads___googleads___v3___common___bidding_pb2___TargetCpa,
    TargetCpm as google___ads___googleads___v3___common___bidding_pb2___TargetCpm,
    TargetImpressionShare as google___ads___googleads___v3___common___bidding_pb2___TargetImpressionShare,
    TargetRoas as google___ads___googleads___v3___common___bidding_pb2___TargetRoas,
    TargetSpend as google___ads___googleads___v3___common___bidding_pb2___TargetSpend,
)
from google.ads.google_ads.v3.proto.common.custom_parameter_pb2 import (
    CustomParameter as google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter,
)
from google.ads.google_ads.v3.proto.common.frequency_cap_pb2 import (
    FrequencyCapEntry as google___ads___googleads___v3___common___frequency_cap_pb2___FrequencyCapEntry,
)
from google.ads.google_ads.v3.proto.common.real_time_bidding_setting_pb2 import (
    RealTimeBiddingSetting as google___ads___googleads___v3___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting,
)
from google.ads.google_ads.v3.proto.common.targeting_setting_pb2 import (
    TargetingSetting as google___ads___googleads___v3___common___targeting_setting_pb2___TargetingSetting,
)
from google.ads.google_ads.v3.proto.enums.ad_serving_optimization_status_pb2 import (
    AdServingOptimizationStatusEnum as google___ads___googleads___v3___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.advertising_channel_sub_type_pb2 import (
    AdvertisingChannelSubTypeEnum as google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.advertising_channel_type_pb2 import (
    AdvertisingChannelTypeEnum as google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.app_campaign_app_store_pb2 import (
    AppCampaignAppStoreEnum as google___ads___googleads___v3___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum,
)
from google.ads.google_ads.v3.proto.enums.app_campaign_bidding_strategy_goal_type_pb2 import (
    AppCampaignBiddingStrategyGoalTypeEnum as google___ads___googleads___v3___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.bidding_strategy_type_pb2 import (
    BiddingStrategyTypeEnum as google___ads___googleads___v3___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.brand_safety_suitability_pb2 import (
    BrandSafetySuitabilityEnum as google___ads___googleads___v3___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum,
)
from google.ads.google_ads.v3.proto.enums.campaign_experiment_type_pb2 import (
    CampaignExperimentTypeEnum as google___ads___googleads___v3___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.campaign_serving_status_pb2 import (
    CampaignServingStatusEnum as google___ads___googleads___v3___enums___campaign_serving_status_pb2___CampaignServingStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.campaign_status_pb2 import (
    CampaignStatusEnum as google___ads___googleads___v3___enums___campaign_status_pb2___CampaignStatusEnum,
)
from google.ads.google_ads.v3.proto.enums.negative_geo_target_type_pb2 import (
    NegativeGeoTargetTypeEnum as google___ads___googleads___v3___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.payment_mode_pb2 import (
    PaymentModeEnum as google___ads___googleads___v3___enums___payment_mode_pb2___PaymentModeEnum,
)
from google.ads.google_ads.v3.proto.enums.positive_geo_target_type_pb2 import (
    PositiveGeoTargetTypeEnum as google___ads___googleads___v3___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum,
)
from google.ads.google_ads.v3.proto.enums.vanity_pharma_display_url_mode_pb2 import (
    VanityPharmaDisplayUrlModeEnum as google___ads___googleads___v3___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum,
)
from google.ads.google_ads.v3.proto.enums.vanity_pharma_text_pb2 import (
    VanityPharmaTextEnum as google___ads___googleads___v3___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Campaign(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class NetworkSettings(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def target_google_search(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def target_search_network(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def target_content_network(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def target_partner_search_network(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        def __init__(
            self,
            *,
            target_google_search: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            target_search_network: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            target_content_network: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            target_partner_search_network: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "target_content_network",
                b"target_content_network",
                "target_google_search",
                b"target_google_search",
                "target_partner_search_network",
                b"target_partner_search_network",
                "target_search_network",
                b"target_search_network",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "target_content_network",
                b"target_content_network",
                "target_google_search",
                b"target_google_search",
                "target_partner_search_network",
                b"target_partner_search_network",
                "target_search_network",
                b"target_search_network",
            ],
        ) -> None: ...
    type___NetworkSettings = NetworkSettings
    class HotelSettingInfo(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def hotel_center_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            hotel_center_id: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "hotel_center_id", b"hotel_center_id"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "hotel_center_id", b"hotel_center_id"
            ],
        ) -> None: ...
    type___HotelSettingInfo = HotelSettingInfo
    class VanityPharma(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        vanity_pharma_display_url_mode: google___ads___googleads___v3___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue = ...
        vanity_pharma_text: google___ads___googleads___v3___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum.VanityPharmaTextValue = ...
        def __init__(
            self,
            *,
            vanity_pharma_display_url_mode: typing___Optional[
                google___ads___googleads___v3___enums___vanity_pharma_display_url_mode_pb2___VanityPharmaDisplayUrlModeEnum.VanityPharmaDisplayUrlModeValue
            ] = None,
            vanity_pharma_text: typing___Optional[
                google___ads___googleads___v3___enums___vanity_pharma_text_pb2___VanityPharmaTextEnum.VanityPharmaTextValue
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "vanity_pharma_display_url_mode",
                b"vanity_pharma_display_url_mode",
                "vanity_pharma_text",
                b"vanity_pharma_text",
            ],
        ) -> None: ...
    type___VanityPharma = VanityPharma
    class DynamicSearchAdsSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def domain_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def language_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def use_supplied_urls_only(
            self,
        ) -> google___protobuf___wrappers_pb2___BoolValue: ...
        @property
        def feeds(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___StringValue
        ]: ...
        def __init__(
            self,
            *,
            domain_name: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            language_code: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            use_supplied_urls_only: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
            feeds: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "domain_name",
                b"domain_name",
                "language_code",
                b"language_code",
                "use_supplied_urls_only",
                b"use_supplied_urls_only",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "domain_name",
                b"domain_name",
                "feeds",
                b"feeds",
                "language_code",
                b"language_code",
                "use_supplied_urls_only",
                b"use_supplied_urls_only",
            ],
        ) -> None: ...
    type___DynamicSearchAdsSetting = DynamicSearchAdsSetting
    class ShoppingSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def merchant_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def sales_country(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def campaign_priority(
            self,
        ) -> google___protobuf___wrappers_pb2___Int32Value: ...
        @property
        def enable_local(self) -> google___protobuf___wrappers_pb2___BoolValue: ...
        def __init__(
            self,
            *,
            merchant_id: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            sales_country: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            campaign_priority: typing___Optional[
                google___protobuf___wrappers_pb2___Int32Value
            ] = None,
            enable_local: typing___Optional[
                google___protobuf___wrappers_pb2___BoolValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "campaign_priority",
                b"campaign_priority",
                "enable_local",
                b"enable_local",
                "merchant_id",
                b"merchant_id",
                "sales_country",
                b"sales_country",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "campaign_priority",
                b"campaign_priority",
                "enable_local",
                b"enable_local",
                "merchant_id",
                b"merchant_id",
                "sales_country",
                b"sales_country",
            ],
        ) -> None: ...
    type___ShoppingSetting = ShoppingSetting
    class GeoTargetTypeSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        positive_geo_target_type: google___ads___googleads___v3___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue = ...
        negative_geo_target_type: google___ads___googleads___v3___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue = ...
        def __init__(
            self,
            *,
            positive_geo_target_type: typing___Optional[
                google___ads___googleads___v3___enums___positive_geo_target_type_pb2___PositiveGeoTargetTypeEnum.PositiveGeoTargetTypeValue
            ] = None,
            negative_geo_target_type: typing___Optional[
                google___ads___googleads___v3___enums___negative_geo_target_type_pb2___NegativeGeoTargetTypeEnum.NegativeGeoTargetTypeValue
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "negative_geo_target_type",
                b"negative_geo_target_type",
                "positive_geo_target_type",
                b"positive_geo_target_type",
            ],
        ) -> None: ...
    type___GeoTargetTypeSetting = GeoTargetTypeSetting
    class TrackingSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def tracking_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        def __init__(
            self,
            *,
            tracking_url: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal["tracking_url", b"tracking_url"],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal["tracking_url", b"tracking_url"],
        ) -> None: ...
    type___TrackingSetting = TrackingSetting
    class AppCampaignSetting(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        bidding_strategy_goal_type: google___ads___googleads___v3___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalTypeValue = ...
        app_store: google___ads___googleads___v3___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum.AppCampaignAppStoreValue = ...
        @property
        def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        def __init__(
            self,
            *,
            bidding_strategy_goal_type: typing___Optional[
                google___ads___googleads___v3___enums___app_campaign_bidding_strategy_goal_type_pb2___AppCampaignBiddingStrategyGoalTypeEnum.AppCampaignBiddingStrategyGoalTypeValue
            ] = None,
            app_id: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            app_store: typing___Optional[
                google___ads___googleads___v3___enums___app_campaign_app_store_pb2___AppCampaignAppStoreEnum.AppCampaignAppStoreValue
            ] = None,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions___Literal["app_id", b"app_id"]
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "app_id",
                b"app_id",
                "app_store",
                b"app_store",
                "bidding_strategy_goal_type",
                b"bidding_strategy_goal_type",
            ],
        ) -> None: ...
    type___AppCampaignSetting = AppCampaignSetting
    class SelectiveOptimization(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def conversion_actions(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___StringValue
        ]: ...
        def __init__(
            self,
            *,
            conversion_actions: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "conversion_actions", b"conversion_actions"
            ],
        ) -> None: ...
    type___SelectiveOptimization = SelectiveOptimization

    resource_name: typing___Text = ...
    status: google___ads___googleads___v3___enums___campaign_status_pb2___CampaignStatusEnum.CampaignStatusValue = ...
    serving_status: google___ads___googleads___v3___enums___campaign_serving_status_pb2___CampaignServingStatusEnum.CampaignServingStatusValue = ...
    ad_serving_optimization_status: google___ads___googleads___v3___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum.AdServingOptimizationStatusValue = ...
    advertising_channel_type: google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue = ...
    advertising_channel_sub_type: google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue = ...
    experiment_type: google___ads___googleads___v3___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum.CampaignExperimentTypeValue = ...
    bidding_strategy_type: google___ads___googleads___v3___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyTypeValue = ...
    video_brand_safety_suitability: google___ads___googleads___v3___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum.BrandSafetySuitabilityValue = ...
    payment_mode: google___ads___googleads___v3___enums___payment_mode_pb2___PaymentModeEnum.PaymentModeValue = ...
    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def tracking_url_template(
        self,
    ) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def url_custom_parameters(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter
    ]: ...
    @property
    def real_time_bidding_setting(
        self,
    ) -> google___ads___googleads___v3___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting: ...
    @property
    def network_settings(self) -> type___Campaign.NetworkSettings: ...
    @property
    def hotel_setting(self) -> type___Campaign.HotelSettingInfo: ...
    @property
    def dynamic_search_ads_setting(self) -> type___Campaign.DynamicSearchAdsSetting: ...
    @property
    def shopping_setting(self) -> type___Campaign.ShoppingSetting: ...
    @property
    def targeting_setting(
        self,
    ) -> google___ads___googleads___v3___common___targeting_setting_pb2___TargetingSetting: ...
    @property
    def geo_target_type_setting(self) -> type___Campaign.GeoTargetTypeSetting: ...
    @property
    def app_campaign_setting(self) -> type___Campaign.AppCampaignSetting: ...
    @property
    def labels(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___protobuf___wrappers_pb2___StringValue
    ]: ...
    @property
    def base_campaign(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def campaign_budget(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def start_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def end_date(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def final_url_suffix(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def frequency_caps(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___common___frequency_cap_pb2___FrequencyCapEntry
    ]: ...
    @property
    def vanity_pharma(self) -> type___Campaign.VanityPharma: ...
    @property
    def selective_optimization(self) -> type___Campaign.SelectiveOptimization: ...
    @property
    def tracking_setting(self) -> type___Campaign.TrackingSetting: ...
    @property
    def optimization_score(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...
    @property
    def bidding_strategy(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def commission(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___Commission: ...
    @property
    def manual_cpc(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___ManualCpc: ...
    @property
    def manual_cpm(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___ManualCpm: ...
    @property
    def manual_cpv(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___ManualCpv: ...
    @property
    def maximize_conversions(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___MaximizeConversions: ...
    @property
    def maximize_conversion_value(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___MaximizeConversionValue: ...
    @property
    def target_cpa(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetCpa: ...
    @property
    def target_impression_share(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetImpressionShare: ...
    @property
    def target_roas(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetRoas: ...
    @property
    def target_spend(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetSpend: ...
    @property
    def percent_cpc(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___PercentCpc: ...
    @property
    def target_cpm(
        self,
    ) -> google___ads___googleads___v3___common___bidding_pb2___TargetCpm: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        id: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status: typing___Optional[
            google___ads___googleads___v3___enums___campaign_status_pb2___CampaignStatusEnum.CampaignStatusValue
        ] = None,
        serving_status: typing___Optional[
            google___ads___googleads___v3___enums___campaign_serving_status_pb2___CampaignServingStatusEnum.CampaignServingStatusValue
        ] = None,
        ad_serving_optimization_status: typing___Optional[
            google___ads___googleads___v3___enums___ad_serving_optimization_status_pb2___AdServingOptimizationStatusEnum.AdServingOptimizationStatusValue
        ] = None,
        advertising_channel_type: typing___Optional[
            google___ads___googleads___v3___enums___advertising_channel_type_pb2___AdvertisingChannelTypeEnum.AdvertisingChannelTypeValue
        ] = None,
        advertising_channel_sub_type: typing___Optional[
            google___ads___googleads___v3___enums___advertising_channel_sub_type_pb2___AdvertisingChannelSubTypeEnum.AdvertisingChannelSubTypeValue
        ] = None,
        tracking_url_template: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        url_custom_parameters: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___custom_parameter_pb2___CustomParameter
            ]
        ] = None,
        real_time_bidding_setting: typing___Optional[
            google___ads___googleads___v3___common___real_time_bidding_setting_pb2___RealTimeBiddingSetting
        ] = None,
        network_settings: typing___Optional[type___Campaign.NetworkSettings] = None,
        hotel_setting: typing___Optional[type___Campaign.HotelSettingInfo] = None,
        dynamic_search_ads_setting: typing___Optional[
            type___Campaign.DynamicSearchAdsSetting
        ] = None,
        shopping_setting: typing___Optional[type___Campaign.ShoppingSetting] = None,
        targeting_setting: typing___Optional[
            google___ads___googleads___v3___common___targeting_setting_pb2___TargetingSetting
        ] = None,
        geo_target_type_setting: typing___Optional[
            type___Campaign.GeoTargetTypeSetting
        ] = None,
        app_campaign_setting: typing___Optional[
            type___Campaign.AppCampaignSetting
        ] = None,
        labels: typing___Optional[
            typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
        ] = None,
        experiment_type: typing___Optional[
            google___ads___googleads___v3___enums___campaign_experiment_type_pb2___CampaignExperimentTypeEnum.CampaignExperimentTypeValue
        ] = None,
        base_campaign: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        campaign_budget: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        bidding_strategy_type: typing___Optional[
            google___ads___googleads___v3___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyTypeValue
        ] = None,
        start_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        end_date: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        final_url_suffix: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        frequency_caps: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___common___frequency_cap_pb2___FrequencyCapEntry
            ]
        ] = None,
        video_brand_safety_suitability: typing___Optional[
            google___ads___googleads___v3___enums___brand_safety_suitability_pb2___BrandSafetySuitabilityEnum.BrandSafetySuitabilityValue
        ] = None,
        vanity_pharma: typing___Optional[type___Campaign.VanityPharma] = None,
        selective_optimization: typing___Optional[
            type___Campaign.SelectiveOptimization
        ] = None,
        tracking_setting: typing___Optional[type___Campaign.TrackingSetting] = None,
        payment_mode: typing___Optional[
            google___ads___googleads___v3___enums___payment_mode_pb2___PaymentModeEnum.PaymentModeValue
        ] = None,
        optimization_score: typing___Optional[
            google___protobuf___wrappers_pb2___DoubleValue
        ] = None,
        bidding_strategy: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        commission: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___Commission
        ] = None,
        manual_cpc: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___ManualCpc
        ] = None,
        manual_cpm: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___ManualCpm
        ] = None,
        manual_cpv: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___ManualCpv
        ] = None,
        maximize_conversions: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___MaximizeConversions
        ] = None,
        maximize_conversion_value: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___MaximizeConversionValue
        ] = None,
        target_cpa: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetCpa
        ] = None,
        target_impression_share: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetImpressionShare
        ] = None,
        target_roas: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetRoas
        ] = None,
        target_spend: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetSpend
        ] = None,
        percent_cpc: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___PercentCpc
        ] = None,
        target_cpm: typing___Optional[
            google___ads___googleads___v3___common___bidding_pb2___TargetCpm
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "app_campaign_setting",
            b"app_campaign_setting",
            "base_campaign",
            b"base_campaign",
            "bidding_strategy",
            b"bidding_strategy",
            "campaign_bidding_strategy",
            b"campaign_bidding_strategy",
            "campaign_budget",
            b"campaign_budget",
            "commission",
            b"commission",
            "dynamic_search_ads_setting",
            b"dynamic_search_ads_setting",
            "end_date",
            b"end_date",
            "final_url_suffix",
            b"final_url_suffix",
            "geo_target_type_setting",
            b"geo_target_type_setting",
            "hotel_setting",
            b"hotel_setting",
            "id",
            b"id",
            "manual_cpc",
            b"manual_cpc",
            "manual_cpm",
            b"manual_cpm",
            "manual_cpv",
            b"manual_cpv",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "network_settings",
            b"network_settings",
            "optimization_score",
            b"optimization_score",
            "percent_cpc",
            b"percent_cpc",
            "real_time_bidding_setting",
            b"real_time_bidding_setting",
            "selective_optimization",
            b"selective_optimization",
            "shopping_setting",
            b"shopping_setting",
            "start_date",
            b"start_date",
            "target_cpa",
            b"target_cpa",
            "target_cpm",
            b"target_cpm",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "targeting_setting",
            b"targeting_setting",
            "tracking_setting",
            b"tracking_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "vanity_pharma",
            b"vanity_pharma",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_serving_optimization_status",
            b"ad_serving_optimization_status",
            "advertising_channel_sub_type",
            b"advertising_channel_sub_type",
            "advertising_channel_type",
            b"advertising_channel_type",
            "app_campaign_setting",
            b"app_campaign_setting",
            "base_campaign",
            b"base_campaign",
            "bidding_strategy",
            b"bidding_strategy",
            "bidding_strategy_type",
            b"bidding_strategy_type",
            "campaign_bidding_strategy",
            b"campaign_bidding_strategy",
            "campaign_budget",
            b"campaign_budget",
            "commission",
            b"commission",
            "dynamic_search_ads_setting",
            b"dynamic_search_ads_setting",
            "end_date",
            b"end_date",
            "experiment_type",
            b"experiment_type",
            "final_url_suffix",
            b"final_url_suffix",
            "frequency_caps",
            b"frequency_caps",
            "geo_target_type_setting",
            b"geo_target_type_setting",
            "hotel_setting",
            b"hotel_setting",
            "id",
            b"id",
            "labels",
            b"labels",
            "manual_cpc",
            b"manual_cpc",
            "manual_cpm",
            b"manual_cpm",
            "manual_cpv",
            b"manual_cpv",
            "maximize_conversion_value",
            b"maximize_conversion_value",
            "maximize_conversions",
            b"maximize_conversions",
            "name",
            b"name",
            "network_settings",
            b"network_settings",
            "optimization_score",
            b"optimization_score",
            "payment_mode",
            b"payment_mode",
            "percent_cpc",
            b"percent_cpc",
            "real_time_bidding_setting",
            b"real_time_bidding_setting",
            "resource_name",
            b"resource_name",
            "selective_optimization",
            b"selective_optimization",
            "serving_status",
            b"serving_status",
            "shopping_setting",
            b"shopping_setting",
            "start_date",
            b"start_date",
            "status",
            b"status",
            "target_cpa",
            b"target_cpa",
            "target_cpm",
            b"target_cpm",
            "target_impression_share",
            b"target_impression_share",
            "target_roas",
            b"target_roas",
            "target_spend",
            b"target_spend",
            "targeting_setting",
            b"targeting_setting",
            "tracking_setting",
            b"tracking_setting",
            "tracking_url_template",
            b"tracking_url_template",
            "url_custom_parameters",
            b"url_custom_parameters",
            "vanity_pharma",
            b"vanity_pharma",
            "video_brand_safety_suitability",
            b"video_brand_safety_suitability",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "campaign_bidding_strategy", b"campaign_bidding_strategy"
        ],
    ) -> typing_extensions___Literal[
        "bidding_strategy",
        "commission",
        "manual_cpc",
        "manual_cpm",
        "manual_cpv",
        "maximize_conversions",
        "maximize_conversion_value",
        "target_cpa",
        "target_impression_share",
        "target_roas",
        "target_spend",
        "percent_cpc",
        "target_cpm",
    ]: ...

type___Campaign = Campaign



from typing import Any

class KeywordPlanKeywordServiceStub:
    GetKeywordPlanKeyword: Any = ...
    MutateKeywordPlanKeywords: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanKeywordServiceServicer:
    def GetKeywordPlanKeyword(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlanKeywords(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanKeywordServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class BudgetTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    BudgetTypeValue = typing___NewType("BudgetTypeValue", builtin___int)
    type___BudgetTypeValue = BudgetTypeValue
    BudgetType: _BudgetType
    class _BudgetType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            BudgetTypeEnum.BudgetTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(BudgetTypeEnum.BudgetTypeValue, 0)
        UNKNOWN = typing___cast(BudgetTypeEnum.BudgetTypeValue, 1)
        STANDARD = typing___cast(BudgetTypeEnum.BudgetTypeValue, 2)
        HOTEL_ADS_COMMISSION = typing___cast(BudgetTypeEnum.BudgetTypeValue, 3)
        FIXED_CPA = typing___cast(BudgetTypeEnum.BudgetTypeValue, 4)
    UNSPECIFIED = typing___cast(BudgetTypeEnum.BudgetTypeValue, 0)
    UNKNOWN = typing___cast(BudgetTypeEnum.BudgetTypeValue, 1)
    STANDARD = typing___cast(BudgetTypeEnum.BudgetTypeValue, 2)
    HOTEL_ADS_COMMISSION = typing___cast(BudgetTypeEnum.BudgetTypeValue, 3)
    FIXED_CPA = typing___cast(BudgetTypeEnum.BudgetTypeValue, 4)
    type___BudgetType = BudgetType
    def __init__(self,) -> None: ...

type___BudgetTypeEnum = BudgetTypeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Iterable as typing___Iterable, Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v5.proto.enums.keyword_plan_competition_level_pb2 import (
    KeywordPlanCompetitionLevelEnum as google___ads___googleads___v5___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum,
)
from google.ads.google_ads.v5.proto.enums.month_of_year_pb2 import (
    MonthOfYearEnum as google___ads___googleads___v5___enums___month_of_year_pb2___MonthOfYearEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class KeywordPlanHistoricalMetrics(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    competition: google___ads___googleads___v5___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue = ...
    @property
    def avg_monthly_searches(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def monthly_search_volumes(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___MonthlySearchVolume
    ]: ...
    @property
    def competition_index(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def low_top_of_page_bid_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def high_top_of_page_bid_micros(
        self,
    ) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        avg_monthly_searches: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        monthly_search_volumes: typing___Optional[
            typing___Iterable[type___MonthlySearchVolume]
        ] = None,
        competition: typing___Optional[
            google___ads___googleads___v5___enums___keyword_plan_competition_level_pb2___KeywordPlanCompetitionLevelEnum.KeywordPlanCompetitionLevelValue
        ] = None,
        competition_index: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        low_top_of_page_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        high_top_of_page_bid_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "avg_monthly_searches",
            b"avg_monthly_searches",
            "competition",
            b"competition",
            "competition_index",
            b"competition_index",
            "high_top_of_page_bid_micros",
            b"high_top_of_page_bid_micros",
            "low_top_of_page_bid_micros",
            b"low_top_of_page_bid_micros",
            "monthly_search_volumes",
            b"monthly_search_volumes",
        ],
    ) -> None: ...

type___KeywordPlanHistoricalMetrics = KeywordPlanHistoricalMetrics

class MonthlySearchVolume(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    month: google___ads___googleads___v5___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue = ...
    @property
    def year(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def monthly_searches(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        year: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        month: typing___Optional[
            google___ads___googleads___v5___enums___month_of_year_pb2___MonthOfYearEnum.MonthOfYearValue
        ] = None,
        monthly_searches: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "monthly_searches", b"monthly_searches", "year", b"year"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "month", b"month", "monthly_searches", b"monthly_searches", "year", b"year"
        ],
    ) -> None: ...

type___MonthlySearchVolume = MonthlySearchVolume



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class AuthenticationErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    AuthenticationErrorValue = typing___NewType(
        "AuthenticationErrorValue", builtin___int
    )
    type___AuthenticationErrorValue = AuthenticationErrorValue
    AuthenticationError: _AuthenticationError
    class _AuthenticationError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            AuthenticationErrorEnum.AuthenticationErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 0)
        UNKNOWN = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 1)
        AUTHENTICATION_ERROR = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 2
        )
        CLIENT_CUSTOMER_ID_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 5
        )
        CUSTOMER_NOT_FOUND = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 8
        )
        GOOGLE_ACCOUNT_DELETED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 9
        )
        GOOGLE_ACCOUNT_COOKIE_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 10
        )
        GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 25
        )
        GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 12
        )
        LOGIN_COOKIE_REQUIRED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 13
        )
        NOT_ADS_USER = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 14
        )
        OAUTH_TOKEN_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 15
        )
        OAUTH_TOKEN_EXPIRED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 16
        )
        OAUTH_TOKEN_DISABLED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 17
        )
        OAUTH_TOKEN_REVOKED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 18
        )
        OAUTH_TOKEN_HEADER_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 19
        )
        LOGIN_COOKIE_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 20
        )
        USER_ID_INVALID = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 22
        )
        TWO_STEP_VERIFICATION_NOT_ENROLLED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 23
        )
        ADVANCED_PROTECTION_NOT_ENROLLED = typing___cast(
            AuthenticationErrorEnum.AuthenticationErrorValue, 24
        )
    UNSPECIFIED = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 0)
    UNKNOWN = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 1)
    AUTHENTICATION_ERROR = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 2
    )
    CLIENT_CUSTOMER_ID_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 5
    )
    CUSTOMER_NOT_FOUND = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 8
    )
    GOOGLE_ACCOUNT_DELETED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 9
    )
    GOOGLE_ACCOUNT_COOKIE_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 10
    )
    GOOGLE_ACCOUNT_AUTHENTICATION_FAILED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 25
    )
    GOOGLE_ACCOUNT_USER_AND_ADS_USER_MISMATCH = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 12
    )
    LOGIN_COOKIE_REQUIRED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 13
    )
    NOT_ADS_USER = typing___cast(AuthenticationErrorEnum.AuthenticationErrorValue, 14)
    OAUTH_TOKEN_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 15
    )
    OAUTH_TOKEN_EXPIRED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 16
    )
    OAUTH_TOKEN_DISABLED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 17
    )
    OAUTH_TOKEN_REVOKED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 18
    )
    OAUTH_TOKEN_HEADER_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 19
    )
    LOGIN_COOKIE_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 20
    )
    USER_ID_INVALID = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 22
    )
    TWO_STEP_VERIFICATION_NOT_ENROLLED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 23
    )
    ADVANCED_PROTECTION_NOT_ENROLLED = typing___cast(
        AuthenticationErrorEnum.AuthenticationErrorValue, 24
    )
    type___AuthenticationError = AuthenticationError
    def __init__(self,) -> None: ...

type___AuthenticationErrorEnum = AuthenticationErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.enums.app_url_operating_system_type_pb2 import (
    AppUrlOperatingSystemTypeEnum as google___ads___googleads___v3___enums___app_url_operating_system_type_pb2___AppUrlOperatingSystemTypeEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FinalAppUrl(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    os_type: google___ads___googleads___v3___enums___app_url_operating_system_type_pb2___AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemTypeValue = ...
    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        os_type: typing___Optional[
            google___ads___googleads___v3___enums___app_url_operating_system_type_pb2___AppUrlOperatingSystemTypeEnum.AppUrlOperatingSystemTypeValue
        ] = None,
        url: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions___Literal["url", b"url"]
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal["os_type", b"os_type", "url", b"url"],
    ) -> None: ...

type___FinalAppUrl = FinalAppUrl



from typing import Any

class CustomInterestServiceStub:
    GetCustomInterest: Any = ...
    MutateCustomInterests: Any = ...
    def __init__(self, channel: Any) -> None: ...

class CustomInterestServiceServicer:
    def GetCustomInterest(self, request: Any, context: Any) -> None: ...
    def MutateCustomInterests(self, request: Any, context: Any) -> None: ...

def add_CustomInterestServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional, Text as typing___Text

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v4.proto.common.click_location_pb2 import (
    ClickLocation as google___ads___googleads___v4___common___click_location_pb2___ClickLocation,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ClickView(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    @property
    def gclid(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def area_of_interest(
        self,
    ) -> google___ads___googleads___v4___common___click_location_pb2___ClickLocation: ...
    @property
    def location_of_presence(
        self,
    ) -> google___ads___googleads___v4___common___click_location_pb2___ClickLocation: ...
    @property
    def page_number(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def ad_group_ad(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        gclid: typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        area_of_interest: typing___Optional[
            google___ads___googleads___v4___common___click_location_pb2___ClickLocation
        ] = None,
        location_of_presence: typing___Optional[
            google___ads___googleads___v4___common___click_location_pb2___ClickLocation
        ] = None,
        page_number: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
        ad_group_ad: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_ad",
            b"ad_group_ad",
            "area_of_interest",
            b"area_of_interest",
            "gclid",
            b"gclid",
            "location_of_presence",
            b"location_of_presence",
            "page_number",
            b"page_number",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "ad_group_ad",
            b"ad_group_ad",
            "area_of_interest",
            b"area_of_interest",
            "gclid",
            b"gclid",
            "location_of_presence",
            b"location_of_presence",
            "page_number",
            b"page_number",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

type___ClickView = ClickView



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import Optional as typing___Optional

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class Money(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    def __init__(
        self,
        *,
        currency_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        amount_micros: typing___Optional[
            google___protobuf___wrappers_pb2___Int64Value
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "amount_micros", b"amount_micros", "currency_code", b"currency_code"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "amount_micros", b"amount_micros", "currency_code", b"currency_code"
        ],
    ) -> None: ...

type___Money = Money



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.resources.payments_account_pb2 import (
    PaymentsAccount as google___ads___googleads___v6___resources___payments_account_pb2___PaymentsAccount,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ListPaymentsAccountsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    def __init__(
        self, *, customer_id: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["customer_id", b"customer_id"]
    ) -> None: ...

type___ListPaymentsAccountsRequest = ListPaymentsAccountsRequest

class ListPaymentsAccountsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def payments_accounts(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v6___resources___payments_account_pb2___PaymentsAccount
    ]: ...
    def __init__(
        self,
        *,
        payments_accounts: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v6___resources___payments_account_pb2___PaymentsAccount
            ]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "payments_accounts", b"payments_accounts"
        ],
    ) -> None: ...

type___ListPaymentsAccountsResponse = ListPaymentsAccountsResponse



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.resources.geo_target_constant_pb2 import (
    GeoTargetConstant as google___ads___googleads___v3___resources___geo_target_constant_pb2___GeoTargetConstant,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetGeoTargetConstantRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetGeoTargetConstantRequest = GetGeoTargetConstantRequest

class SuggestGeoTargetConstantsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class LocationNames(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def names(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___StringValue
        ]: ...
        def __init__(
            self,
            *,
            names: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
            ] = None,
        ) -> None: ...
        def ClearField(
            self, field_name: typing_extensions___Literal["names", b"names"]
        ) -> None: ...
    type___LocationNames = LocationNames
    class GeoTargets(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def geo_target_constants(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___protobuf___wrappers_pb2___StringValue
        ]: ...
        def __init__(
            self,
            *,
            geo_target_constants: typing___Optional[
                typing___Iterable[google___protobuf___wrappers_pb2___StringValue]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "geo_target_constants", b"geo_target_constants"
            ],
        ) -> None: ...
    type___GeoTargets = GeoTargets
    @property
    def locale(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def location_names(
        self,
    ) -> type___SuggestGeoTargetConstantsRequest.LocationNames: ...
    @property
    def geo_targets(self) -> type___SuggestGeoTargetConstantsRequest.GeoTargets: ...
    def __init__(
        self,
        *,
        locale: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        country_code: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        location_names: typing___Optional[
            type___SuggestGeoTargetConstantsRequest.LocationNames
        ] = None,
        geo_targets: typing___Optional[
            type___SuggestGeoTargetConstantsRequest.GeoTargets
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "country_code",
            b"country_code",
            "geo_targets",
            b"geo_targets",
            "locale",
            b"locale",
            "location_names",
            b"location_names",
            "query",
            b"query",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "country_code",
            b"country_code",
            "geo_targets",
            b"geo_targets",
            "locale",
            b"locale",
            "location_names",
            b"location_names",
            "query",
            b"query",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["query", b"query"]
    ) -> typing_extensions___Literal["location_names", "geo_targets"]: ...

type___SuggestGeoTargetConstantsRequest = SuggestGeoTargetConstantsRequest

class SuggestGeoTargetConstantsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def geo_target_constant_suggestions(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___GeoTargetConstantSuggestion
    ]: ...
    def __init__(
        self,
        *,
        geo_target_constant_suggestions: typing___Optional[
            typing___Iterable[type___GeoTargetConstantSuggestion]
        ] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "geo_target_constant_suggestions", b"geo_target_constant_suggestions"
        ],
    ) -> None: ...

type___SuggestGeoTargetConstantsResponse = SuggestGeoTargetConstantsResponse

class GeoTargetConstantSuggestion(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def locale(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def reach(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
    @property
    def search_term(self) -> google___protobuf___wrappers_pb2___StringValue: ...
    @property
    def geo_target_constant(
        self,
    ) -> google___ads___googleads___v3___resources___geo_target_constant_pb2___GeoTargetConstant: ...
    @property
    def geo_target_constant_parents(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___resources___geo_target_constant_pb2___GeoTargetConstant
    ]: ...
    def __init__(
        self,
        *,
        locale: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        reach: typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        search_term: typing___Optional[
            google___protobuf___wrappers_pb2___StringValue
        ] = None,
        geo_target_constant: typing___Optional[
            google___ads___googleads___v3___resources___geo_target_constant_pb2___GeoTargetConstant
        ] = None,
        geo_target_constant_parents: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___resources___geo_target_constant_pb2___GeoTargetConstant
            ]
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "geo_target_constant",
            b"geo_target_constant",
            "locale",
            b"locale",
            "reach",
            b"reach",
            "search_term",
            b"search_term",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "geo_target_constant",
            b"geo_target_constant",
            "geo_target_constant_parents",
            b"geo_target_constant_parents",
            "locale",
            b"locale",
            "reach",
            b"reach",
            "search_term",
            b"search_term",
        ],
    ) -> None: ...

type___GeoTargetConstantSuggestion = GeoTargetConstantSuggestion



from typing import Any

class OperatingSystemVersionConstantServiceStub:
    GetOperatingSystemVersionConstant: Any = ...
    def __init__(self, channel: Any) -> None: ...

class OperatingSystemVersionConstantServiceServicer:
    def GetOperatingSystemVersionConstant(self, request: Any, context: Any) -> None: ...

def add_OperatingSystemVersionConstantServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any

class ClickViewServiceStub:
    GetClickView: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ClickViewServiceServicer:
    def GetClickView(self, request: Any, context: Any) -> None: ...

def add_ClickViewServiceServicer_to_server(servicer: Any, server: Any) -> None: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedScalarFieldContainer as google___protobuf___internal___containers___RepeatedScalarFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class UrlCollection(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    url_collection_id: typing___Text = ...
    final_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    final_mobile_urls: google___protobuf___internal___containers___RepeatedScalarFieldContainer[
        typing___Text
    ] = ...
    tracking_url_template: typing___Text = ...
    def __init__(
        self,
        *,
        url_collection_id: typing___Optional[typing___Text] = None,
        final_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        final_mobile_urls: typing___Optional[typing___Iterable[typing___Text]] = None,
        tracking_url_template: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_tracking_url_template",
            b"_tracking_url_template",
            "_url_collection_id",
            b"_url_collection_id",
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_tracking_url_template",
            b"_tracking_url_template",
            "_url_collection_id",
            b"_url_collection_id",
            "final_mobile_urls",
            b"final_mobile_urls",
            "final_urls",
            b"final_urls",
            "tracking_url_template",
            b"tracking_url_template",
            "url_collection_id",
            b"url_collection_id",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_tracking_url_template", b"_tracking_url_template"
        ],
    ) -> typing_extensions___Literal["tracking_url_template"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_url_collection_id", b"_url_collection_id"
        ],
    ) -> typing_extensions___Literal["url_collection_id"]: ...

type___UrlCollection = UrlCollection



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class FeedMappingErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    FeedMappingErrorValue = typing___NewType("FeedMappingErrorValue", builtin___int)
    type___FeedMappingErrorValue = FeedMappingErrorValue
    FeedMappingError: _FeedMappingError
    class _FeedMappingError(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            FeedMappingErrorEnum.FeedMappingErrorValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(FeedMappingErrorEnum.FeedMappingErrorValue, 0)
        UNKNOWN = typing___cast(FeedMappingErrorEnum.FeedMappingErrorValue, 1)
        INVALID_PLACEHOLDER_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 2
        )
        INVALID_CRITERION_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 3
        )
        INVALID_PLACEHOLDER_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 4
        )
        INVALID_CRITERION_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 5
        )
        NO_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 7
        )
        FEED_ATTRIBUTE_TYPE_MISMATCH = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 8
        )
        CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 9
        )
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 10
        )
        MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 11
        )
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 12
        )
        MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 13
        )
        UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 14
        )
        LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 15
        )
        CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 16
        )
        INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 17
        )
        INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 18
        )
        ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD = typing___cast(
            FeedMappingErrorEnum.FeedMappingErrorValue, 19
        )
    UNSPECIFIED = typing___cast(FeedMappingErrorEnum.FeedMappingErrorValue, 0)
    UNKNOWN = typing___cast(FeedMappingErrorEnum.FeedMappingErrorValue, 1)
    INVALID_PLACEHOLDER_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 2
    )
    INVALID_CRITERION_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 3
    )
    INVALID_PLACEHOLDER_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 4
    )
    INVALID_CRITERION_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 5
    )
    NO_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 7
    )
    FEED_ATTRIBUTE_TYPE_MISMATCH = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 8
    )
    CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 9
    )
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 10
    )
    MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 11
    )
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 12
    )
    MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 13
    )
    UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 14
    )
    LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 15
    )
    CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 16
    )
    INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 17
    )
    INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 18
    )
    ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD = typing___cast(
        FeedMappingErrorEnum.FeedMappingErrorValue, 19
    )
    type___FeedMappingError = FeedMappingError
    def __init__(self,) -> None: ...

type___FeedMappingErrorEnum = FeedMappingErrorEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
    overload as typing___overload,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v6.proto.enums.user_identifier_source_pb2 import (
    UserIdentifierSourceEnum as google___ads___googleads___v6___enums___user_identifier_source_pb2___UserIdentifierSourceEnum,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class OfflineUserAddressInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    hashed_first_name: typing___Text = ...
    hashed_last_name: typing___Text = ...
    city: typing___Text = ...
    state: typing___Text = ...
    country_code: typing___Text = ...
    postal_code: typing___Text = ...
    def __init__(
        self,
        *,
        hashed_first_name: typing___Optional[typing___Text] = None,
        hashed_last_name: typing___Optional[typing___Text] = None,
        city: typing___Optional[typing___Text] = None,
        state: typing___Optional[typing___Text] = None,
        country_code: typing___Optional[typing___Text] = None,
        postal_code: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_city",
            b"_city",
            "_country_code",
            b"_country_code",
            "_hashed_first_name",
            b"_hashed_first_name",
            "_hashed_last_name",
            b"_hashed_last_name",
            "_postal_code",
            b"_postal_code",
            "_state",
            b"_state",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "hashed_first_name",
            b"hashed_first_name",
            "hashed_last_name",
            b"hashed_last_name",
            "postal_code",
            b"postal_code",
            "state",
            b"state",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_city",
            b"_city",
            "_country_code",
            b"_country_code",
            "_hashed_first_name",
            b"_hashed_first_name",
            "_hashed_last_name",
            b"_hashed_last_name",
            "_postal_code",
            b"_postal_code",
            "_state",
            b"_state",
            "city",
            b"city",
            "country_code",
            b"country_code",
            "hashed_first_name",
            b"hashed_first_name",
            "hashed_last_name",
            b"hashed_last_name",
            "postal_code",
            b"postal_code",
            "state",
            b"state",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_city", b"_city"]
    ) -> typing_extensions___Literal["city"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_country_code", b"_country_code"],
    ) -> typing_extensions___Literal["country_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hashed_first_name", b"_hashed_first_name"
        ],
    ) -> typing_extensions___Literal["hashed_first_name"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_hashed_last_name", b"_hashed_last_name"
        ],
    ) -> typing_extensions___Literal["hashed_last_name"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_postal_code", b"_postal_code"]
    ) -> typing_extensions___Literal["postal_code"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_state", b"_state"]
    ) -> typing_extensions___Literal["state"]: ...

type___OfflineUserAddressInfo = OfflineUserAddressInfo

class UserIdentifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    user_identifier_source: google___ads___googleads___v6___enums___user_identifier_source_pb2___UserIdentifierSourceEnum.UserIdentifierSourceValue = ...
    hashed_email: typing___Text = ...
    hashed_phone_number: typing___Text = ...
    mobile_id: typing___Text = ...
    third_party_user_id: typing___Text = ...
    @property
    def address_info(self) -> type___OfflineUserAddressInfo: ...
    def __init__(
        self,
        *,
        user_identifier_source: typing___Optional[
            google___ads___googleads___v6___enums___user_identifier_source_pb2___UserIdentifierSourceEnum.UserIdentifierSourceValue
        ] = None,
        hashed_email: typing___Optional[typing___Text] = None,
        hashed_phone_number: typing___Optional[typing___Text] = None,
        mobile_id: typing___Optional[typing___Text] = None,
        third_party_user_id: typing___Optional[typing___Text] = None,
        address_info: typing___Optional[type___OfflineUserAddressInfo] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "address_info",
            b"address_info",
            "hashed_email",
            b"hashed_email",
            "hashed_phone_number",
            b"hashed_phone_number",
            "identifier",
            b"identifier",
            "mobile_id",
            b"mobile_id",
            "third_party_user_id",
            b"third_party_user_id",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "address_info",
            b"address_info",
            "hashed_email",
            b"hashed_email",
            "hashed_phone_number",
            b"hashed_phone_number",
            "identifier",
            b"identifier",
            "mobile_id",
            b"mobile_id",
            "third_party_user_id",
            b"third_party_user_id",
            "user_identifier_source",
            b"user_identifier_source",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["identifier", b"identifier"]
    ) -> typing_extensions___Literal[
        "hashed_email",
        "hashed_phone_number",
        "mobile_id",
        "third_party_user_id",
        "address_info",
    ]: ...

type___UserIdentifier = UserIdentifier

class TransactionAttribute(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    transaction_date_time: typing___Text = ...
    transaction_amount_micros: builtin___float = ...
    currency_code: typing___Text = ...
    conversion_action: typing___Text = ...
    order_id: typing___Text = ...
    custom_value: typing___Text = ...
    @property
    def store_attribute(self) -> type___StoreAttribute: ...
    def __init__(
        self,
        *,
        transaction_date_time: typing___Optional[typing___Text] = None,
        transaction_amount_micros: typing___Optional[builtin___float] = None,
        currency_code: typing___Optional[typing___Text] = None,
        conversion_action: typing___Optional[typing___Text] = None,
        order_id: typing___Optional[typing___Text] = None,
        store_attribute: typing___Optional[type___StoreAttribute] = None,
        custom_value: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_conversion_action",
            b"_conversion_action",
            "_currency_code",
            b"_currency_code",
            "_custom_value",
            b"_custom_value",
            "_order_id",
            b"_order_id",
            "_transaction_amount_micros",
            b"_transaction_amount_micros",
            "_transaction_date_time",
            b"_transaction_date_time",
            "conversion_action",
            b"conversion_action",
            "currency_code",
            b"currency_code",
            "custom_value",
            b"custom_value",
            "order_id",
            b"order_id",
            "store_attribute",
            b"store_attribute",
            "transaction_amount_micros",
            b"transaction_amount_micros",
            "transaction_date_time",
            b"transaction_date_time",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_conversion_action",
            b"_conversion_action",
            "_currency_code",
            b"_currency_code",
            "_custom_value",
            b"_custom_value",
            "_order_id",
            b"_order_id",
            "_transaction_amount_micros",
            b"_transaction_amount_micros",
            "_transaction_date_time",
            b"_transaction_date_time",
            "conversion_action",
            b"conversion_action",
            "currency_code",
            b"currency_code",
            "custom_value",
            b"custom_value",
            "order_id",
            b"order_id",
            "store_attribute",
            b"store_attribute",
            "transaction_amount_micros",
            b"transaction_amount_micros",
            "transaction_date_time",
            b"transaction_date_time",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_conversion_action", b"_conversion_action"
        ],
    ) -> typing_extensions___Literal["conversion_action"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_currency_code", b"_currency_code"],
    ) -> typing_extensions___Literal["currency_code"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal["_custom_value", b"_custom_value"],
    ) -> typing_extensions___Literal["custom_value"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_order_id", b"_order_id"]
    ) -> typing_extensions___Literal["order_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_transaction_amount_micros", b"_transaction_amount_micros"
        ],
    ) -> typing_extensions___Literal["transaction_amount_micros"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_transaction_date_time", b"_transaction_date_time"
        ],
    ) -> typing_extensions___Literal["transaction_date_time"]: ...

type___TransactionAttribute = TransactionAttribute

class StoreAttribute(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    store_code: typing___Text = ...
    def __init__(
        self, *, store_code: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_store_code", b"_store_code", "store_code", b"store_code"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_store_code", b"_store_code", "store_code", b"store_code"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_store_code", b"_store_code"]
    ) -> typing_extensions___Literal["store_code"]: ...

type___StoreAttribute = StoreAttribute

class UserData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def user_identifiers(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___UserIdentifier
    ]: ...
    @property
    def transaction_attribute(self) -> type___TransactionAttribute: ...
    @property
    def user_attribute(self) -> type___UserAttribute: ...
    def __init__(
        self,
        *,
        user_identifiers: typing___Optional[
            typing___Iterable[type___UserIdentifier]
        ] = None,
        transaction_attribute: typing___Optional[type___TransactionAttribute] = None,
        user_attribute: typing___Optional[type___UserAttribute] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "transaction_attribute",
            b"transaction_attribute",
            "user_attribute",
            b"user_attribute",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "transaction_attribute",
            b"transaction_attribute",
            "user_attribute",
            b"user_attribute",
            "user_identifiers",
            b"user_identifiers",
        ],
    ) -> None: ...

type___UserData = UserData

class UserAttribute(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    lifetime_value_micros: builtin___int = ...
    lifetime_value_bucket: builtin___int = ...
    def __init__(
        self,
        *,
        lifetime_value_micros: typing___Optional[builtin___int] = None,
        lifetime_value_bucket: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_lifetime_value_bucket",
            b"_lifetime_value_bucket",
            "_lifetime_value_micros",
            b"_lifetime_value_micros",
            "lifetime_value_bucket",
            b"lifetime_value_bucket",
            "lifetime_value_micros",
            b"lifetime_value_micros",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_lifetime_value_bucket",
            b"_lifetime_value_bucket",
            "_lifetime_value_micros",
            b"_lifetime_value_micros",
            "lifetime_value_bucket",
            b"lifetime_value_bucket",
            "lifetime_value_micros",
            b"lifetime_value_micros",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_lifetime_value_bucket", b"_lifetime_value_bucket"
        ],
    ) -> typing_extensions___Literal["lifetime_value_bucket"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_lifetime_value_micros", b"_lifetime_value_micros"
        ],
    ) -> typing_extensions___Literal["lifetime_value_micros"]: ...

type___UserAttribute = UserAttribute

class CustomerMatchUserListMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    user_list: typing___Text = ...
    def __init__(
        self, *, user_list: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_user_list", b"_user_list", "user_list", b"user_list"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_user_list", b"_user_list"]
    ) -> typing_extensions___Literal["user_list"]: ...

type___CustomerMatchUserListMetadata = CustomerMatchUserListMetadata

class StoreSalesMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    loyalty_fraction: builtin___float = ...
    transaction_upload_fraction: builtin___float = ...
    custom_key: typing___Text = ...
    @property
    def third_party_metadata(self) -> type___StoreSalesThirdPartyMetadata: ...
    def __init__(
        self,
        *,
        loyalty_fraction: typing___Optional[builtin___float] = None,
        transaction_upload_fraction: typing___Optional[builtin___float] = None,
        custom_key: typing___Optional[typing___Text] = None,
        third_party_metadata: typing___Optional[
            type___StoreSalesThirdPartyMetadata
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_custom_key",
            b"_custom_key",
            "_loyalty_fraction",
            b"_loyalty_fraction",
            "_transaction_upload_fraction",
            b"_transaction_upload_fraction",
            "custom_key",
            b"custom_key",
            "loyalty_fraction",
            b"loyalty_fraction",
            "third_party_metadata",
            b"third_party_metadata",
            "transaction_upload_fraction",
            b"transaction_upload_fraction",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_custom_key",
            b"_custom_key",
            "_loyalty_fraction",
            b"_loyalty_fraction",
            "_transaction_upload_fraction",
            b"_transaction_upload_fraction",
            "custom_key",
            b"custom_key",
            "loyalty_fraction",
            b"loyalty_fraction",
            "third_party_metadata",
            b"third_party_metadata",
            "transaction_upload_fraction",
            b"transaction_upload_fraction",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_custom_key", b"_custom_key"]
    ) -> typing_extensions___Literal["custom_key"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_loyalty_fraction", b"_loyalty_fraction"
        ],
    ) -> typing_extensions___Literal["loyalty_fraction"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_transaction_upload_fraction", b"_transaction_upload_fraction"
        ],
    ) -> typing_extensions___Literal["transaction_upload_fraction"]: ...

type___StoreSalesMetadata = StoreSalesMetadata

class StoreSalesThirdPartyMetadata(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    advertiser_upload_date_time: typing___Text = ...
    valid_transaction_fraction: builtin___float = ...
    partner_match_fraction: builtin___float = ...
    partner_upload_fraction: builtin___float = ...
    bridge_map_version_id: typing___Text = ...
    partner_id: builtin___int = ...
    def __init__(
        self,
        *,
        advertiser_upload_date_time: typing___Optional[typing___Text] = None,
        valid_transaction_fraction: typing___Optional[builtin___float] = None,
        partner_match_fraction: typing___Optional[builtin___float] = None,
        partner_upload_fraction: typing___Optional[builtin___float] = None,
        bridge_map_version_id: typing___Optional[typing___Text] = None,
        partner_id: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "_advertiser_upload_date_time",
            b"_advertiser_upload_date_time",
            "_bridge_map_version_id",
            b"_bridge_map_version_id",
            "_partner_id",
            b"_partner_id",
            "_partner_match_fraction",
            b"_partner_match_fraction",
            "_partner_upload_fraction",
            b"_partner_upload_fraction",
            "_valid_transaction_fraction",
            b"_valid_transaction_fraction",
            "advertiser_upload_date_time",
            b"advertiser_upload_date_time",
            "bridge_map_version_id",
            b"bridge_map_version_id",
            "partner_id",
            b"partner_id",
            "partner_match_fraction",
            b"partner_match_fraction",
            "partner_upload_fraction",
            b"partner_upload_fraction",
            "valid_transaction_fraction",
            b"valid_transaction_fraction",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "_advertiser_upload_date_time",
            b"_advertiser_upload_date_time",
            "_bridge_map_version_id",
            b"_bridge_map_version_id",
            "_partner_id",
            b"_partner_id",
            "_partner_match_fraction",
            b"_partner_match_fraction",
            "_partner_upload_fraction",
            b"_partner_upload_fraction",
            "_valid_transaction_fraction",
            b"_valid_transaction_fraction",
            "advertiser_upload_date_time",
            b"advertiser_upload_date_time",
            "bridge_map_version_id",
            b"bridge_map_version_id",
            "partner_id",
            b"partner_id",
            "partner_match_fraction",
            b"partner_match_fraction",
            "partner_upload_fraction",
            b"partner_upload_fraction",
            "valid_transaction_fraction",
            b"valid_transaction_fraction",
        ],
    ) -> None: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_advertiser_upload_date_time", b"_advertiser_upload_date_time"
        ],
    ) -> typing_extensions___Literal["advertiser_upload_date_time"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_bridge_map_version_id", b"_bridge_map_version_id"
        ],
    ) -> typing_extensions___Literal["bridge_map_version_id"]: ...
    @typing___overload
    def WhichOneof(
        self, oneof_group: typing_extensions___Literal["_partner_id", b"_partner_id"]
    ) -> typing_extensions___Literal["partner_id"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_partner_match_fraction", b"_partner_match_fraction"
        ],
    ) -> typing_extensions___Literal["partner_match_fraction"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_partner_upload_fraction", b"_partner_upload_fraction"
        ],
    ) -> typing_extensions___Literal["partner_upload_fraction"]: ...
    @typing___overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "_valid_transaction_fraction", b"_valid_transaction_fraction"
        ],
    ) -> typing_extensions___Literal["valid_transaction_fraction"]: ...

type___StoreSalesThirdPartyMetadata = StoreSalesThirdPartyMetadata



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class PolicyTopicEntryTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    PolicyTopicEntryTypeValue = typing___NewType(
        "PolicyTopicEntryTypeValue", builtin___int
    )
    type___PolicyTopicEntryTypeValue = PolicyTopicEntryTypeValue
    PolicyTopicEntryType: _PolicyTopicEntryType
    class _PolicyTopicEntryType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 0
        )
        UNKNOWN = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 1)
        PROHIBITED = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 2
        )
        LIMITED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 4)
        FULLY_LIMITED = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 8
        )
        DESCRIPTIVE = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 5
        )
        BROADENING = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 6
        )
        AREA_OF_INTEREST_ONLY = typing___cast(
            PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 7
        )
    UNSPECIFIED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 0)
    UNKNOWN = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 1)
    PROHIBITED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 2)
    LIMITED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 4)
    FULLY_LIMITED = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 8)
    DESCRIPTIVE = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 5)
    BROADENING = typing___cast(PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 6)
    AREA_OF_INTEREST_ONLY = typing___cast(
        PolicyTopicEntryTypeEnum.PolicyTopicEntryTypeValue, 7
    )
    type___PolicyTopicEntryType = PolicyTopicEntryType
    def __init__(self,) -> None: ...

type___PolicyTopicEntryTypeEnum = PolicyTopicEntryTypeEnum



from typing import Any

class ExtensionFeedItemServiceStub:
    GetExtensionFeedItem: Any = ...
    MutateExtensionFeedItems: Any = ...
    def __init__(self, channel: Any) -> None: ...

class ExtensionFeedItemServiceServicer:
    def GetExtensionFeedItem(self, request: Any, context: Any) -> None: ...
    def MutateExtensionFeedItems(self, request: Any, context: Any) -> None: ...

def add_ExtensionFeedItemServiceServicer_to_server(
    servicer: Any, server: Any
) -> None: ...



from typing import Any, Dict, Optional, Union

from google.oauth2.credentials import Credentials  # type: ignore
from typing_extensions import Literal

from google.ads.google_ads.config import _ConfigDataUnparsed

_V3 = Literal["v3"]
_V4 = Literal["v4"]
_V5 = Literal["v5"]
_V6 = Literal["v6"]
_V = Union[_V3, _V4, _V5, _V6]

class GoogleAdsClient:
    credentials: Credentials = ...
    developer_token: str = ...
    endpoint: Optional[str] = ...
    login_customer_id: Optional[str] = ...
    @classmethod
    def load_from_env(cls) -> GoogleAdsClient: ...
    @classmethod
    def load_from_string(cls, yaml_str: str) -> GoogleAdsClient: ...
    @classmethod
    def load_from_storage(cls, path: Optional[str] = ...) -> GoogleAdsClient: ...
    @classmethod
    def load_from_dict(cls, config_dict: _ConfigDataUnparsed) -> GoogleAdsClient: ...
    def __init__(
        self,
        credentials: Credentials,
        developer_token: str,
        endpoint: Optional[str] = ...,
        login_customer_id: Optional[str] = ...,
        logging_config: Optional[Dict[Any, Any]] = ...,
    ) -> None: ...
    @classmethod
    def get_type(cls, name: str, version: _V = ...) -> Any: ...
    def get_service(self, name: str, version: _V = ...) -> Any: ...



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class ReachPlanAgeRangeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ReachPlanAgeRangeValue = typing___NewType("ReachPlanAgeRangeValue", builtin___int)
    type___ReachPlanAgeRangeValue = ReachPlanAgeRangeValue
    ReachPlanAgeRange: _ReachPlanAgeRange
    class _ReachPlanAgeRange(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 0)
        UNKNOWN = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 1)
        AGE_RANGE_18_24 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503001
        )
        AGE_RANGE_18_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 2)
        AGE_RANGE_18_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 3)
        AGE_RANGE_18_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 4)
        AGE_RANGE_18_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 5)
        AGE_RANGE_18_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 6)
        AGE_RANGE_18_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 7
        )
        AGE_RANGE_21_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 8)
        AGE_RANGE_25_34 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503002
        )
        AGE_RANGE_25_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 9)
        AGE_RANGE_25_49 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 10
        )
        AGE_RANGE_25_54 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 11
        )
        AGE_RANGE_25_64 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 12
        )
        AGE_RANGE_25_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 13
        )
        AGE_RANGE_35_44 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503003
        )
        AGE_RANGE_35_49 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 14
        )
        AGE_RANGE_35_54 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 15
        )
        AGE_RANGE_35_64 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 16
        )
        AGE_RANGE_35_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 17
        )
        AGE_RANGE_45_54 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503004
        )
        AGE_RANGE_45_64 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 18
        )
        AGE_RANGE_45_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 19
        )
        AGE_RANGE_50_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 20
        )
        AGE_RANGE_55_64 = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503005
        )
        AGE_RANGE_55_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 21
        )
        AGE_RANGE_65_UP = typing___cast(
            ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503006
        )
    UNSPECIFIED = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 0)
    UNKNOWN = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 1)
    AGE_RANGE_18_24 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503001
    )
    AGE_RANGE_18_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 2)
    AGE_RANGE_18_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 3)
    AGE_RANGE_18_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 4)
    AGE_RANGE_18_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 5)
    AGE_RANGE_18_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 6)
    AGE_RANGE_18_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 7)
    AGE_RANGE_21_34 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 8)
    AGE_RANGE_25_34 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503002
    )
    AGE_RANGE_25_44 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 9)
    AGE_RANGE_25_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 10)
    AGE_RANGE_25_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 11)
    AGE_RANGE_25_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 12)
    AGE_RANGE_25_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 13)
    AGE_RANGE_35_44 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503003
    )
    AGE_RANGE_35_49 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 14)
    AGE_RANGE_35_54 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 15)
    AGE_RANGE_35_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 16)
    AGE_RANGE_35_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 17)
    AGE_RANGE_45_54 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503004
    )
    AGE_RANGE_45_64 = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 18)
    AGE_RANGE_45_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 19)
    AGE_RANGE_50_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 20)
    AGE_RANGE_55_64 = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503005
    )
    AGE_RANGE_55_65_UP = typing___cast(ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 21)
    AGE_RANGE_65_UP = typing___cast(
        ReachPlanAgeRangeEnum.ReachPlanAgeRangeValue, 503006
    )
    type___ReachPlanAgeRange = ReachPlanAgeRange
    def __init__(self,) -> None: ...

type___ReachPlanAgeRangeEnum = ReachPlanAgeRangeEnum



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)
from google.rpc.status_pb2 import Status as google___rpc___status_pb2___Status
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.common.extensions_pb2 import (
    CallFeedItem as google___ads___googleads___v3___common___extensions_pb2___CallFeedItem,
    CalloutFeedItem as google___ads___googleads___v3___common___extensions_pb2___CalloutFeedItem,
    SitelinkFeedItem as google___ads___googleads___v3___common___extensions_pb2___SitelinkFeedItem,
)
from google.ads.google_ads.v3.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v3___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)
from google.ads.google_ads.v3.proto.resources.ad_pb2 import (
    Ad as google___ads___googleads___v3___resources___ad_pb2___Ad,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetRecommendationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetRecommendationRequest = GetRecommendationRequest

class ApplyRecommendationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ApplyRecommendationOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operations: typing___Optional[
            typing___Iterable[type___ApplyRecommendationOperation]
        ] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "partial_failure",
            b"partial_failure",
        ],
    ) -> None: ...

type___ApplyRecommendationRequest = ApplyRecommendationRequest

class ApplyRecommendationOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignBudgetParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def new_budget_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            new_budget_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "new_budget_amount_micros", b"new_budget_amount_micros"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "new_budget_amount_micros", b"new_budget_amount_micros"
            ],
        ) -> None: ...
    type___CampaignBudgetParameters = CampaignBudgetParameters
    class TextAdParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def ad(self) -> google___ads___googleads___v3___resources___ad_pb2___Ad: ...
        def __init__(
            self,
            *,
            ad: typing___Optional[
                google___ads___googleads___v3___resources___ad_pb2___Ad
            ] = None,
        ) -> None: ...
        def HasField(
            self, field_name: typing_extensions___Literal["ad", b"ad"]
        ) -> builtin___bool: ...
        def ClearField(
            self, field_name: typing_extensions___Literal["ad", b"ad"]
        ) -> None: ...
    type___TextAdParameters = TextAdParameters
    class KeywordParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        match_type: google___ads___googleads___v3___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue = ...
        @property
        def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...
        @property
        def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            ad_group: typing___Optional[
                google___protobuf___wrappers_pb2___StringValue
            ] = None,
            match_type: typing___Optional[
                google___ads___googleads___v3___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchTypeValue
            ] = None,
            cpc_bid_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "ad_group", b"ad_group", "cpc_bid_micros", b"cpc_bid_micros"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "ad_group",
                b"ad_group",
                "cpc_bid_micros",
                b"cpc_bid_micros",
                "match_type",
                b"match_type",
            ],
        ) -> None: ...
    type___KeywordParameters = KeywordParameters
    class TargetCpaOptInParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def target_cpa_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        @property
        def new_campaign_budget_amount_micros(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            target_cpa_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
            new_campaign_budget_amount_micros: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "new_campaign_budget_amount_micros",
                b"new_campaign_budget_amount_micros",
                "target_cpa_micros",
                b"target_cpa_micros",
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "new_campaign_budget_amount_micros",
                b"new_campaign_budget_amount_micros",
                "target_cpa_micros",
                b"target_cpa_micros",
            ],
        ) -> None: ...
    type___TargetCpaOptInParameters = TargetCpaOptInParameters
    class CalloutExtensionParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def callout_extensions(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___ads___googleads___v3___common___extensions_pb2___CalloutFeedItem
        ]: ...
        def __init__(
            self,
            *,
            callout_extensions: typing___Optional[
                typing___Iterable[
                    google___ads___googleads___v3___common___extensions_pb2___CalloutFeedItem
                ]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "callout_extensions", b"callout_extensions"
            ],
        ) -> None: ...
    type___CalloutExtensionParameters = CalloutExtensionParameters
    class CallExtensionParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def call_extensions(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___ads___googleads___v3___common___extensions_pb2___CallFeedItem
        ]: ...
        def __init__(
            self,
            *,
            call_extensions: typing___Optional[
                typing___Iterable[
                    google___ads___googleads___v3___common___extensions_pb2___CallFeedItem
                ]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "call_extensions", b"call_extensions"
            ],
        ) -> None: ...
    type___CallExtensionParameters = CallExtensionParameters
    class SitelinkExtensionParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def sitelink_extensions(
            self,
        ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
            google___ads___googleads___v3___common___extensions_pb2___SitelinkFeedItem
        ]: ...
        def __init__(
            self,
            *,
            sitelink_extensions: typing___Optional[
                typing___Iterable[
                    google___ads___googleads___v3___common___extensions_pb2___SitelinkFeedItem
                ]
            ] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "sitelink_extensions", b"sitelink_extensions"
            ],
        ) -> None: ...
    type___SitelinkExtensionParameters = SitelinkExtensionParameters
    class MoveUnusedBudgetParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        @property
        def budget_micros_to_move(
            self,
        ) -> google___protobuf___wrappers_pb2___Int64Value: ...
        def __init__(
            self,
            *,
            budget_micros_to_move: typing___Optional[
                google___protobuf___wrappers_pb2___Int64Value
            ] = None,
        ) -> None: ...
        def HasField(
            self,
            field_name: typing_extensions___Literal[
                "budget_micros_to_move", b"budget_micros_to_move"
            ],
        ) -> builtin___bool: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal[
                "budget_micros_to_move", b"budget_micros_to_move"
            ],
        ) -> None: ...
    type___MoveUnusedBudgetParameters = MoveUnusedBudgetParameters

    resource_name: typing___Text = ...
    @property
    def campaign_budget(
        self,
    ) -> type___ApplyRecommendationOperation.CampaignBudgetParameters: ...
    @property
    def text_ad(self) -> type___ApplyRecommendationOperation.TextAdParameters: ...
    @property
    def keyword(self) -> type___ApplyRecommendationOperation.KeywordParameters: ...
    @property
    def target_cpa_opt_in(
        self,
    ) -> type___ApplyRecommendationOperation.TargetCpaOptInParameters: ...
    @property
    def callout_extension(
        self,
    ) -> type___ApplyRecommendationOperation.CalloutExtensionParameters: ...
    @property
    def call_extension(
        self,
    ) -> type___ApplyRecommendationOperation.CallExtensionParameters: ...
    @property
    def sitelink_extension(
        self,
    ) -> type___ApplyRecommendationOperation.SitelinkExtensionParameters: ...
    @property
    def move_unused_budget(
        self,
    ) -> type___ApplyRecommendationOperation.MoveUnusedBudgetParameters: ...
    def __init__(
        self,
        *,
        resource_name: typing___Optional[typing___Text] = None,
        campaign_budget: typing___Optional[
            type___ApplyRecommendationOperation.CampaignBudgetParameters
        ] = None,
        text_ad: typing___Optional[
            type___ApplyRecommendationOperation.TextAdParameters
        ] = None,
        keyword: typing___Optional[
            type___ApplyRecommendationOperation.KeywordParameters
        ] = None,
        target_cpa_opt_in: typing___Optional[
            type___ApplyRecommendationOperation.TargetCpaOptInParameters
        ] = None,
        callout_extension: typing___Optional[
            type___ApplyRecommendationOperation.CalloutExtensionParameters
        ] = None,
        call_extension: typing___Optional[
            type___ApplyRecommendationOperation.CallExtensionParameters
        ] = None,
        sitelink_extension: typing___Optional[
            type___ApplyRecommendationOperation.SitelinkExtensionParameters
        ] = None,
        move_unused_budget: typing___Optional[
            type___ApplyRecommendationOperation.MoveUnusedBudgetParameters
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "apply_parameters",
            b"apply_parameters",
            "call_extension",
            b"call_extension",
            "callout_extension",
            b"callout_extension",
            "campaign_budget",
            b"campaign_budget",
            "keyword",
            b"keyword",
            "move_unused_budget",
            b"move_unused_budget",
            "sitelink_extension",
            b"sitelink_extension",
            "target_cpa_opt_in",
            b"target_cpa_opt_in",
            "text_ad",
            b"text_ad",
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "apply_parameters",
            b"apply_parameters",
            "call_extension",
            b"call_extension",
            "callout_extension",
            b"callout_extension",
            "campaign_budget",
            b"campaign_budget",
            "keyword",
            b"keyword",
            "move_unused_budget",
            b"move_unused_budget",
            "resource_name",
            b"resource_name",
            "sitelink_extension",
            b"sitelink_extension",
            "target_cpa_opt_in",
            b"target_cpa_opt_in",
            "text_ad",
            b"text_ad",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions___Literal[
            "apply_parameters", b"apply_parameters"
        ],
    ) -> typing_extensions___Literal[
        "campaign_budget",
        "text_ad",
        "keyword",
        "target_cpa_opt_in",
        "callout_extension",
        "call_extension",
        "sitelink_extension",
        "move_unused_budget",
    ]: ...

type___ApplyRecommendationOperation = ApplyRecommendationOperation

class ApplyRecommendationResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___ApplyRecommendationResult
    ]: ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    def __init__(
        self,
        *,
        results: typing___Optional[
            typing___Iterable[type___ApplyRecommendationResult]
        ] = None,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

type___ApplyRecommendationResponse = ApplyRecommendationResponse

class ApplyRecommendationResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___ApplyRecommendationResult = ApplyRecommendationResult

class DismissRecommendationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class DismissRecommendationOperation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        resource_name: typing___Text = ...
        def __init__(
            self, *, resource_name: typing___Optional[typing___Text] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal["resource_name", b"resource_name"],
        ) -> None: ...
    type___DismissRecommendationOperation = DismissRecommendationOperation

    customer_id: typing___Text = ...
    partial_failure: builtin___bool = ...
    @property
    def operations(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___DismissRecommendationRequest.DismissRecommendationOperation
    ]: ...
    def __init__(
        self,
        *,
        customer_id: typing___Optional[typing___Text] = None,
        operations: typing___Optional[
            typing___Iterable[
                type___DismissRecommendationRequest.DismissRecommendationOperation
            ]
        ] = None,
        partial_failure: typing___Optional[builtin___bool] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "customer_id",
            b"customer_id",
            "operations",
            b"operations",
            "partial_failure",
            b"partial_failure",
        ],
    ) -> None: ...

type___DismissRecommendationRequest = DismissRecommendationRequest

class DismissRecommendationResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class DismissRecommendationResult(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        resource_name: typing___Text = ...
        def __init__(
            self, *, resource_name: typing___Optional[typing___Text] = None,
        ) -> None: ...
        def ClearField(
            self,
            field_name: typing_extensions___Literal["resource_name", b"resource_name"],
        ) -> None: ...
    type___DismissRecommendationResult = DismissRecommendationResult
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        type___DismissRecommendationResponse.DismissRecommendationResult
    ]: ...
    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...
    def __init__(
        self,
        *,
        results: typing___Optional[
            typing___Iterable[
                type___DismissRecommendationResponse.DismissRecommendationResult
            ]
        ] = None,
        partial_failure_error: typing___Optional[
            google___rpc___status_pb2___Status
        ] = None,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error"
        ],
    ) -> builtin___bool: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "partial_failure_error", b"partial_failure_error", "results", b"results"
        ],
    ) -> None: ...

type___DismissRecommendationResponse = DismissRecommendationResponse



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)
from google.protobuf.message import Message as google___protobuf___message___Message
from typing_extensions import Literal as typing_extensions___Literal

from google.ads.google_ads.v3.proto.resources.google_ads_field_pb2 import (
    GoogleAdsField as google___ads___googleads___v3___resources___google_ads_field_pb2___GoogleAdsField,
)

builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class GetGoogleAdsFieldRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name: typing___Text = ...
    def __init__(
        self, *, resource_name: typing___Optional[typing___Text] = None,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions___Literal["resource_name", b"resource_name"]
    ) -> None: ...

type___GetGoogleAdsFieldRequest = GetGoogleAdsFieldRequest

class SearchGoogleAdsFieldsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    query: typing___Text = ...
    page_token: typing___Text = ...
    page_size: builtin___int = ...
    def __init__(
        self,
        *,
        query: typing___Optional[typing___Text] = None,
        page_token: typing___Optional[typing___Text] = None,
        page_size: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "page_size", b"page_size", "page_token", b"page_token", "query", b"query"
        ],
    ) -> None: ...

type___SearchGoogleAdsFieldsRequest = SearchGoogleAdsFieldsRequest

class SearchGoogleAdsFieldsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token: typing___Text = ...
    total_results_count: builtin___int = ...
    @property
    def results(
        self,
    ) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[
        google___ads___googleads___v3___resources___google_ads_field_pb2___GoogleAdsField
    ]: ...
    def __init__(
        self,
        *,
        results: typing___Optional[
            typing___Iterable[
                google___ads___googleads___v3___resources___google_ads_field_pb2___GoogleAdsField
            ]
        ] = None,
        next_page_token: typing___Optional[typing___Text] = None,
        total_results_count: typing___Optional[builtin___int] = None,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions___Literal[
            "next_page_token",
            b"next_page_token",
            "results",
            b"results",
            "total_results_count",
            b"total_results_count",
        ],
    ) -> None: ...

type___SearchGoogleAdsFieldsResponse = SearchGoogleAdsFieldsResponse



# @generated by mypy-protobuf.  Do not edit manually!
import sys
from typing import NewType as typing___NewType, cast as typing___cast

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
    FileDescriptor as google___protobuf___descriptor___FileDescriptor,
)
from google.protobuf.internal.enum_type_wrapper import (
    _EnumTypeWrapper as google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper,
)
from google.protobuf.message import Message as google___protobuf___message___Message

builtin___int = int

DESCRIPTOR: google___protobuf___descriptor___FileDescriptor = ...

class LeadFormPostSubmitCallToActionTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    LeadFormPostSubmitCallToActionTypeValue = typing___NewType(
        "LeadFormPostSubmitCallToActionTypeValue", builtin___int
    )
    type___LeadFormPostSubmitCallToActionTypeValue = (
        LeadFormPostSubmitCallToActionTypeValue
    )
    LeadFormPostSubmitCallToActionType: _LeadFormPostSubmitCallToActionType
    class _LeadFormPostSubmitCallToActionType(
        google___protobuf___internal___enum_type_wrapper____EnumTypeWrapper[
            LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue
        ]
    ):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        UNSPECIFIED = typing___cast(
            LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
            0,
        )
        UNKNOWN = typing___cast(
            LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
            1,
        )
        VISIT_SITE = typing___cast(
            LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
            2,
        )
        DOWNLOAD = typing___cast(
            LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
            3,
        )
        LEARN_MORE = typing___cast(
            LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
            4,
        )
        SHOP_NOW = typing___cast(
            LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
            5,
        )
    UNSPECIFIED = typing___cast(
        LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
        0,
    )
    UNKNOWN = typing___cast(
        LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
        1,
    )
    VISIT_SITE = typing___cast(
        LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
        2,
    )
    DOWNLOAD = typing___cast(
        LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
        3,
    )
    LEARN_MORE = typing___cast(
        LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
        4,
    )
    SHOP_NOW = typing___cast(
        LeadFormPostSubmitCallToActionTypeEnum.LeadFormPostSubmitCallToActionTypeValue,
        5,
    )
    type___LeadFormPostSubmitCallToActionType = LeadFormPostSubmitCallToActionType
    def __init__(self,) -> None: ...

type___LeadFormPostSubmitCallToActionTypeEnum = LeadFormPostSubmitCallToActionTypeEnum



from typing import Any

class KeywordPlanServiceStub:
    GetKeywordPlan: Any = ...
    MutateKeywordPlans: Any = ...
    GenerateForecastMetrics: Any = ...
    GenerateHistoricalMetrics: Any = ...
    def __init__(self, channel: Any) -> None: ...

class KeywordPlanServiceServicer:
    def GetKeywordPlan(self, request: Any, context: Any) -> None: ...
    def MutateKeywordPlans(self, request: Any, context: Any) -> None: ...
    def GenerateForecastMetrics(self, request: Any, context: Any) -> None: ...
    def GenerateHistoricalMetrics(self, request: Any, context: Any) -> None: ...

def add_KeywordPlanServiceServicer_to_server(servicer: Any, server: Any) -> None: ...
